==> nextcloud-app-contacts-8.3.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/contacts/l10n/ia.js <==
OC.L10N.register(
    "contacts",
    {
    "Details" : "Detalios",
    "All contacts" : "Tote contactos",
    "Contacts" : "Contactos",
    "Rename" : "Renominar",
    "Send email" : "Inviar message de e-posta",
    "Delete" : "Deler",
    "Copy link" : "Copiar ligamine",
    "Download" : "Discargar",
    "Share with users or groups" : "Compartir con usatores o gruppos",
    "can edit" : "pote modificar",
    "Cancel" : "Cancellar",
    "Add" : "Adder",
    "First name" : "Prime nomine",
    "Last name" : "Ultime nomine",
    "Display name" : "Monstrar nomine",
    "Save" : "Salveguardar",
    "Close" : "Clauder",
    "Folder" : "Folder",
    "Create" : "Crear",
    "Invalid image" : "Imagine invalide",
    "Name" : "Nomine",
    "Title" : "Titulo",
    "Move" : "Move",
    "Pending" : "Pendente",
    "None" : "Nulle",
    "New contact" : "Nove contacto",
    "Import" : "Importar",
    "Not grouped" : "Non gruppate",
    "User" : "User",
    "Group" : "Gruppo",
    "Email" : "E-posta",
    "Owner" : "Owner",
    "Detailed name" : "Nomine detaliate",
    "Additional names" : "Nomines additional",
    "Prefix" : "Prefixo",
    "Suffix" : "Suffixo",
    "Nickname" : "Pseudonymo",
    "Notes" : "Notas",
    "Website" : "Sito web",
    "Location" : "Loco",
    "Federated Cloud ID" : "ID del Nube Federate",
    "Home" : "Domo",
    "Work" : "Travalio",
    "Other" : "Altere",
    "Address" : "Adresse",
    "Post office box" : "Cassa postal",
    "City" : "Citate",
    "State or province" : "Stato o provincia",
    "Postal code" : "Codice postal",
    "Country" : "Pais",
    "Birthday" : "Anniversario de nativitate",
    "Anniversary" : "Anniversario de evento",
    "Date of death" : "Data de morte",
    "Instant messaging" : "Messageria instantanee",
    "Phone" : "Phono",
    "Mobile" : "Mobile",
    "Fax" : "Fax",
    "Fax home" : "Fax a domicilio",
    "Fax work" : "Fax a travalio",
    "Pager" : "Pager",
    "Voice" : "Voce",
    "Social network" : "Medios Social",
    "Relative" : "Relative",
    "Unknown" : "Incognite"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-contacts-8.3.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/contacts/l10n/ia.js <==
OC.L10N.register(
    "contacts",
    {
    "Details" : "Detalios",
    "All contacts" : "Tote contactos",
    "Contacts" : "Contactos",
    "Rename" : "Renominar",
    "Send email" : "Inviar message de e-posta",
    "Delete" : "Deler",
    "Copy link" : "Copiar ligamine",
    "Download" : "Discargar",
    "Share with users or groups" : "Compartir con usatores o gruppos",
    "Cancel" : "Cancellar",
    "Add" : "Adder",
    "First name" : "Prime nomine",
    "Last name" : "Ultime nomine",
    "Display name" : "Monstrar nomine",
    "Save" : "Salveguardar",
    "Close" : "Clauder",
    "Folder" : "Folder",
    "Create" : "Crear",
    "Invalid image" : "Imagine invalide",
    "Name" : "Nomine",
    "Title" : "Titulo",
    "Move" : "Move",
    "Pending" : "Pendente",
    "None" : "Nulle",
    "New contact" : "Nove contacto",
    "Import" : "Importar",
    "Not grouped" : "Non gruppate",
    "User" : "User",
    "Group" : "Gruppo",
    "Email" : "E-posta",
    "Owner" : "Owner",
    "Detailed name" : "Nomine detaliate",
    "Additional names" : "Nomines additional",
    "Prefix" : "Prefixo",
    "Suffix" : "Suffixo",
    "Nickname" : "Pseudonymo",
    "Notes" : "Notas",
    "Website" : "Sito web",
    "Location" : "Loco",
    "Federated Cloud ID" : "ID del Nube Federate",
    "Home" : "Domo",
    "Work" : "Travalio",
    "Other" : "Altere",
    "Address" : "Adresse",
    "Post office box" : "Cassa postal",
    "City" : "Citate",
    "State or province" : "Stato o provincia",
    "Postal code" : "Codice postal",
    "Country" : "Pais",
    "Birthday" : "Anniversario de nativitate",
    "Anniversary" : "Anniversario de evento",
    "Date of death" : "Data de morte",
    "Instant messaging" : "Messageria instantanee",
    "Phone" : "Phono",
    "Mobile" : "Mobile",
    "Fax" : "Fax",
    "Fax home" : "Fax a domicilio",
    "Fax work" : "Fax a travalio",
    "Pager" : "Pager",
    "Voice" : "Voce",
    "Social network" : "Medios Social",
    "Relative" : "Relative",
    "Unknown" : "Incognite",
    "can edit" : "pote modificar"
},
"nplurals=2; plural=(n != 1);");
